# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'Nagstamon/QUI/settings_server.ui'
#
# Created by: PyQt5 UI code generator 5.15.4
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_settings_server(object):
    def setupUi(self, settings_server):
        settings_server.setObjectName("settings_server")
        settings_server.resize(659, 1231)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(settings_server.sizePolicy().hasHeightForWidth())
        settings_server.setSizePolicy(sizePolicy)
        settings_server.setModal(True)
        self.gridLayout = QtWidgets.QGridLayout(settings_server)
        self.gridLayout.setContentsMargins(10, 10, 10, 10)
        self.gridLayout.setHorizontalSpacing(5)
        self.gridLayout.setVerticalSpacing(2)
        self.gridLayout.setObjectName("gridLayout")
        self.label_password = QtWidgets.QLabel(settings_server)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_password.sizePolicy().hasHeightForWidth())
        self.label_password.setSizePolicy(sizePolicy)
        self.label_password.setObjectName("label_password")
        self.gridLayout.addWidget(self.label_password, 8, 0, 1, 1)
        self.input_lineedit_monitor_url = QtWidgets.QLineEdit(settings_server)
        self.input_lineedit_monitor_url.setInputMask("")
        self.input_lineedit_monitor_url.setObjectName("input_lineedit_monitor_url")
        self.gridLayout.addWidget(self.input_lineedit_monitor_url, 4, 2, 1, 2)
        self.label_name = QtWidgets.QLabel(settings_server)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_name.sizePolicy().hasHeightForWidth())
        self.label_name.setSizePolicy(sizePolicy)
        self.label_name.setObjectName("label_name")
        self.gridLayout.addWidget(self.label_name, 3, 0, 1, 1)
        self.input_lineedit_username = QtWidgets.QLineEdit(settings_server)
        self.input_lineedit_username.setObjectName("input_lineedit_username")
        self.gridLayout.addWidget(self.input_lineedit_username, 6, 2, 1, 1)
        self.input_lineedit_monitor_cgi_url = QtWidgets.QLineEdit(settings_server)
        self.input_lineedit_monitor_cgi_url.setObjectName("input_lineedit_monitor_cgi_url")
        self.gridLayout.addWidget(self.input_lineedit_monitor_cgi_url, 5, 2, 1, 2)
        self.input_combobox_type = QtWidgets.QComboBox(settings_server)
        self.input_combobox_type.setObjectName("input_combobox_type")
        self.gridLayout.addWidget(self.input_combobox_type, 1, 2, 1, 1)
        self.input_lineedit_password = QtWidgets.QLineEdit(settings_server)
        self.input_lineedit_password.setEchoMode(QtWidgets.QLineEdit.Password)
        self.input_lineedit_password.setObjectName("input_lineedit_password")
        self.gridLayout.addWidget(self.input_lineedit_password, 8, 2, 1, 1)
        self.input_checkbox_use_proxy = QtWidgets.QCheckBox(settings_server)
        self.input_checkbox_use_proxy.setObjectName("input_checkbox_use_proxy")
        self.gridLayout.addWidget(self.input_checkbox_use_proxy, 17, 0, 1, 1)
        self.groupbox_proxy = QtWidgets.QGroupBox(settings_server)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupbox_proxy.sizePolicy().hasHeightForWidth())
        self.groupbox_proxy.setSizePolicy(sizePolicy)
        self.groupbox_proxy.setObjectName("groupbox_proxy")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupbox_proxy)
        self.gridLayout_2.setContentsMargins(10, 10, 10, 10)
        self.gridLayout_2.setSpacing(5)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.label_proxy_password = QtWidgets.QLabel(self.groupbox_proxy)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_proxy_password.sizePolicy().hasHeightForWidth())
        self.label_proxy_password.setSizePolicy(sizePolicy)
        self.label_proxy_password.setObjectName("label_proxy_password")
        self.gridLayout_2.addWidget(self.label_proxy_password, 3, 0, 1, 1)
        self.label_proxy_username = QtWidgets.QLabel(self.groupbox_proxy)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_proxy_username.sizePolicy().hasHeightForWidth())
        self.label_proxy_username.setSizePolicy(sizePolicy)
        self.label_proxy_username.setObjectName("label_proxy_username")
        self.gridLayout_2.addWidget(self.label_proxy_username, 2, 0, 1, 1)
        self.input_lineedit_proxy_username = QtWidgets.QLineEdit(self.groupbox_proxy)
        self.input_lineedit_proxy_username.setObjectName("input_lineedit_proxy_username")
        self.gridLayout_2.addWidget(self.input_lineedit_proxy_username, 2, 1, 1, 1)
        self.input_lineedit_proxy_address = QtWidgets.QLineEdit(self.groupbox_proxy)
        self.input_lineedit_proxy_address.setObjectName("input_lineedit_proxy_address")
        self.gridLayout_2.addWidget(self.input_lineedit_proxy_address, 1, 1, 1, 1)
        self.label_proxy_address = QtWidgets.QLabel(self.groupbox_proxy)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_proxy_address.sizePolicy().hasHeightForWidth())
        self.label_proxy_address.setSizePolicy(sizePolicy)
        self.label_proxy_address.setObjectName("label_proxy_address")
        self.gridLayout_2.addWidget(self.label_proxy_address, 1, 0, 1, 1)
        self.input_lineedit_proxy_password = QtWidgets.QLineEdit(self.groupbox_proxy)
        self.input_lineedit_proxy_password.setEchoMode(QtWidgets.QLineEdit.Password)
        self.input_lineedit_proxy_password.setObjectName("input_lineedit_proxy_password")
        self.gridLayout_2.addWidget(self.input_lineedit_proxy_password, 3, 1, 1, 1)
        self.input_checkbox_use_proxy_from_os = QtWidgets.QCheckBox(self.groupbox_proxy)
        self.input_checkbox_use_proxy_from_os.setObjectName("input_checkbox_use_proxy_from_os")
        self.gridLayout_2.addWidget(self.input_checkbox_use_proxy_from_os, 4, 0, 1, 2)
        self.gridLayout.addWidget(self.groupbox_proxy, 18, 0, 1, 4)
        self.button_box = QtWidgets.QDialogButtonBox(settings_server)
        self.button_box.setOrientation(QtCore.Qt.Horizontal)
        self.button_box.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.button_box.setObjectName("button_box")
        self.gridLayout.addWidget(self.button_box, 29, 3, 1, 1)
        self.label_server_type = QtWidgets.QLabel(settings_server)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_server_type.sizePolicy().hasHeightForWidth())
        self.label_server_type.setSizePolicy(sizePolicy)
        self.label_server_type.setObjectName("label_server_type")
        self.gridLayout.addWidget(self.label_server_type, 1, 0, 1, 1)
        self.label_username = QtWidgets.QLabel(settings_server)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_username.sizePolicy().hasHeightForWidth())
        self.label_username.setSizePolicy(sizePolicy)
        self.label_username.setObjectName("label_username")
        self.gridLayout.addWidget(self.label_username, 6, 0, 1, 1)
        self.label_monitor_url = QtWidgets.QLabel(settings_server)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_monitor_url.sizePolicy().hasHeightForWidth())
        self.label_monitor_url.setSizePolicy(sizePolicy)
        self.label_monitor_url.setObjectName("label_monitor_url")
        self.gridLayout.addWidget(self.label_monitor_url, 4, 0, 1, 1)
        self.input_lineedit_name = QtWidgets.QLineEdit(settings_server)
        self.input_lineedit_name.setObjectName("input_lineedit_name")
        self.gridLayout.addWidget(self.input_lineedit_name, 3, 2, 1, 2)
        self.label_monitor_cgi_url = QtWidgets.QLabel(settings_server)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_monitor_cgi_url.sizePolicy().hasHeightForWidth())
        self.label_monitor_cgi_url.setSizePolicy(sizePolicy)
        self.label_monitor_cgi_url.setObjectName("label_monitor_cgi_url")
        self.gridLayout.addWidget(self.label_monitor_cgi_url, 5, 0, 1, 1)
        self.input_checkbox_enabled = QtWidgets.QCheckBox(settings_server)
        self.input_checkbox_enabled.setObjectName("input_checkbox_enabled")
        self.gridLayout.addWidget(self.input_checkbox_enabled, 0, 0, 1, 4)
        self.input_checkbox_save_password = QtWidgets.QCheckBox(settings_server)
        self.input_checkbox_save_password.setObjectName("input_checkbox_save_password")
        self.gridLayout.addWidget(self.input_checkbox_save_password, 8, 3, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout.addItem(spacerItem, 26, 0, 1, 4)
        self.input_checkbox_show_options = QtWidgets.QCheckBox(settings_server)
        self.input_checkbox_show_options.setObjectName("input_checkbox_show_options")
        self.gridLayout.addWidget(self.input_checkbox_show_options, 27, 0, 1, 4)
        self.groupbox_options = QtWidgets.QGroupBox(settings_server)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupbox_options.sizePolicy().hasHeightForWidth())
        self.groupbox_options.setSizePolicy(sizePolicy)
        self.groupbox_options.setObjectName("groupbox_options")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.groupbox_options)
        self.gridLayout_3.setContentsMargins(10, 10, 10, 10)
        self.gridLayout_3.setHorizontalSpacing(10)
        self.gridLayout_3.setVerticalSpacing(5)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.input_lineedit_custom_cert_ca_file = QtWidgets.QLineEdit(self.groupbox_options)
        self.input_lineedit_custom_cert_ca_file.setObjectName("input_lineedit_custom_cert_ca_file")
        self.horizontalLayout.addWidget(self.input_lineedit_custom_cert_ca_file)
        self.button_choose_custom_cert_ca_file = QtWidgets.QPushButton(self.groupbox_options)
        self.button_choose_custom_cert_ca_file.setObjectName("button_choose_custom_cert_ca_file")
        self.horizontalLayout.addWidget(self.button_choose_custom_cert_ca_file)
        self.gridLayout_3.addLayout(self.horizontalLayout, 2, 2, 1, 2)
        self.input_checkbox_use_autologin = QtWidgets.QCheckBox(self.groupbox_options)
        self.input_checkbox_use_autologin.setObjectName("input_checkbox_use_autologin")
        self.gridLayout_3.addWidget(self.input_checkbox_use_autologin, 7, 1, 1, 3)
        self.input_lineedit_alertmanager_filter = QtWidgets.QLineEdit(self.groupbox_options)
        self.input_lineedit_alertmanager_filter.setObjectName("input_lineedit_alertmanager_filter")
        self.gridLayout_3.addWidget(self.input_lineedit_alertmanager_filter, 12, 2, 1, 2)
        self.label_map_to_hostname = QtWidgets.QLabel(self.groupbox_options)
        self.label_map_to_hostname.setObjectName("label_map_to_hostname")
        self.gridLayout_3.addWidget(self.label_map_to_hostname, 13, 1, 1, 1)
        self.input_lineedit_map_to_hostname = QtWidgets.QLineEdit(self.groupbox_options)
        self.input_lineedit_map_to_hostname.setObjectName("input_lineedit_map_to_hostname")
        self.gridLayout_3.addWidget(self.input_lineedit_map_to_hostname, 13, 2, 1, 2)
        self.input_checkbox_use_display_name_service = QtWidgets.QCheckBox(self.groupbox_options)
        self.input_checkbox_use_display_name_service.setObjectName("input_checkbox_use_display_name_service")
        self.gridLayout_3.addWidget(self.input_checkbox_use_display_name_service, 22, 1, 1, 3)
        self.input_lineedit_autologin_key = QtWidgets.QLineEdit(self.groupbox_options)
        self.input_lineedit_autologin_key.setText("")
        self.input_lineedit_autologin_key.setObjectName("input_lineedit_autologin_key")
        self.gridLayout_3.addWidget(self.input_lineedit_autologin_key, 9, 2, 1, 2)
        self.input_lineedit_map_to_ok = QtWidgets.QLineEdit(self.groupbox_options)
        self.input_lineedit_map_to_ok.setObjectName("input_lineedit_map_to_ok")
        self.gridLayout_3.addWidget(self.input_lineedit_map_to_ok, 16, 2, 1, 2)
        self.label_idp_ecp_endpoint = QtWidgets.QLabel(self.groupbox_options)
        self.label_idp_ecp_endpoint.setObjectName("label_idp_ecp_endpoint")
        self.gridLayout_3.addWidget(self.label_idp_ecp_endpoint, 26, 1, 1, 1)
        self.label_alertmanager_filter = QtWidgets.QLabel(self.groupbox_options)
        self.label_alertmanager_filter.setObjectName("label_alertmanager_filter")
        self.gridLayout_3.addWidget(self.label_alertmanager_filter, 12, 1, 1, 1)
        self.label_map_to_servicename = QtWidgets.QLabel(self.groupbox_options)
        self.label_map_to_servicename.setObjectName("label_map_to_servicename")
        self.gridLayout_3.addWidget(self.label_map_to_servicename, 14, 1, 1, 1)
        self.input_checkbox_custom_cert_use = QtWidgets.QCheckBox(self.groupbox_options)
        self.input_checkbox_custom_cert_use.setObjectName("input_checkbox_custom_cert_use")
        self.gridLayout_3.addWidget(self.input_checkbox_custom_cert_use, 1, 1, 1, 2)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_3.addItem(spacerItem1, 6, 3, 1, 1)
        self.input_lineedit_service_filter = QtWidgets.QLineEdit(self.groupbox_options)
        self.input_lineedit_service_filter.setText("")
        self.input_lineedit_service_filter.setObjectName("input_lineedit_service_filter")
        self.gridLayout_3.addWidget(self.input_lineedit_service_filter, 11, 2, 1, 2)
        self.label_timeout = QtWidgets.QLabel(self.groupbox_options)
        self.label_timeout.setObjectName("label_timeout")
        self.gridLayout_3.addWidget(self.label_timeout, 6, 1, 1, 1)
        self.input_checkbox_force_authuser = QtWidgets.QCheckBox(self.groupbox_options)
        self.input_checkbox_force_authuser.setObjectName("input_checkbox_force_authuser")
        self.gridLayout_3.addWidget(self.input_checkbox_force_authuser, 24, 1, 1, 3)
        self.input_lineedit_map_to_status_information = QtWidgets.QLineEdit(self.groupbox_options)
        self.input_lineedit_map_to_status_information.setObjectName("input_lineedit_map_to_status_information")
        self.gridLayout_3.addWidget(self.input_lineedit_map_to_status_information, 15, 2, 1, 2)
        self.input_checkbox_no_cookie_auth = QtWidgets.QCheckBox(self.groupbox_options)
        self.input_checkbox_no_cookie_auth.setObjectName("input_checkbox_no_cookie_auth")
        self.gridLayout_3.addWidget(self.input_checkbox_no_cookie_auth, 20, 1, 1, 3)
        self.label_autologin_key = QtWidgets.QLabel(self.groupbox_options)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_autologin_key.sizePolicy().hasHeightForWidth())
        self.label_autologin_key.setSizePolicy(sizePolicy)
        self.label_autologin_key.setObjectName("label_autologin_key")
        self.gridLayout_3.addWidget(self.label_autologin_key, 9, 1, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_3.addItem(spacerItem2, 5, 3, 1, 1)
        self.input_lineedit_idp_ecp_endpoint = QtWidgets.QLineEdit(self.groupbox_options)
        self.input_lineedit_idp_ecp_endpoint.setObjectName("input_lineedit_idp_ecp_endpoint")
        self.gridLayout_3.addWidget(self.input_lineedit_idp_ecp_endpoint, 26, 2, 1, 2)
        self.label_auth_type = QtWidgets.QLabel(self.groupbox_options)
        self.label_auth_type.setObjectName("label_auth_type")
        self.gridLayout_3.addWidget(self.label_auth_type, 5, 1, 1, 1)
        self.label_service_filter = QtWidgets.QLabel(self.groupbox_options)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_service_filter.sizePolicy().hasHeightForWidth())
        self.label_service_filter.setSizePolicy(sizePolicy)
        self.label_service_filter.setObjectName("label_service_filter")
        self.gridLayout_3.addWidget(self.label_service_filter, 11, 1, 1, 1)
        self.horizontalLayout_timeout_seconds = QtWidgets.QHBoxLayout()
        self.horizontalLayout_timeout_seconds.setSpacing(5)
        self.horizontalLayout_timeout_seconds.setObjectName("horizontalLayout_timeout_seconds")
        self.input_spinbox_timeout = QtWidgets.QSpinBox(self.groupbox_options)
        self.input_spinbox_timeout.setObjectName("input_spinbox_timeout")
        self.horizontalLayout_timeout_seconds.addWidget(self.input_spinbox_timeout)
        self.label_timeout_sec = QtWidgets.QLabel(self.groupbox_options)
        self.label_timeout_sec.setObjectName("label_timeout_sec")
        self.horizontalLayout_timeout_seconds.addWidget(self.label_timeout_sec)
        self.gridLayout_3.addLayout(self.horizontalLayout_timeout_seconds, 6, 2, 1, 1)
        self.label_monitor_site = QtWidgets.QLabel(self.groupbox_options)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_monitor_site.sizePolicy().hasHeightForWidth())
        self.label_monitor_site.setSizePolicy(sizePolicy)
        self.label_monitor_site.setObjectName("label_monitor_site")
        self.gridLayout_3.addWidget(self.label_monitor_site, 8, 1, 1, 1)
        self.input_checkbox_use_description_name_service = QtWidgets.QCheckBox(self.groupbox_options)
        self.input_checkbox_use_description_name_service.setObjectName("input_checkbox_use_description_name_service")
        self.gridLayout_3.addWidget(self.input_checkbox_use_description_name_service, 23, 1, 1, 3)
        self.input_combobox_authentication = QtWidgets.QComboBox(self.groupbox_options)
        self.input_combobox_authentication.setObjectName("input_combobox_authentication")
        self.gridLayout_3.addWidget(self.input_combobox_authentication, 5, 2, 1, 1)
        self.groupbox_checkmk_views = QtWidgets.QGroupBox(self.groupbox_options)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupbox_checkmk_views.sizePolicy().hasHeightForWidth())
        self.groupbox_checkmk_views.setSizePolicy(sizePolicy)
        self.groupbox_checkmk_views.setObjectName("groupbox_checkmk_views")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.groupbox_checkmk_views)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.label_checkmk_view_hosts = QtWidgets.QLabel(self.groupbox_checkmk_views)
        self.label_checkmk_view_hosts.setObjectName("label_checkmk_view_hosts")
        self.gridLayout_4.addWidget(self.label_checkmk_view_hosts, 0, 0, 1, 1)
        self.label_checkmk_view_services = QtWidgets.QLabel(self.groupbox_checkmk_views)
        self.label_checkmk_view_services.setObjectName("label_checkmk_view_services")
        self.gridLayout_4.addWidget(self.label_checkmk_view_services, 1, 0, 1, 1)
        self.input_lineedit_checkmk_view_services = QtWidgets.QLineEdit(self.groupbox_checkmk_views)
        self.input_lineedit_checkmk_view_services.setObjectName("input_lineedit_checkmk_view_services")
        self.gridLayout_4.addWidget(self.input_lineedit_checkmk_view_services, 1, 1, 1, 1)
        self.input_lineedit_checkmk_view_hosts = QtWidgets.QLineEdit(self.groupbox_checkmk_views)
        self.input_lineedit_checkmk_view_hosts.setObjectName("input_lineedit_checkmk_view_hosts")
        self.gridLayout_4.addWidget(self.input_lineedit_checkmk_view_hosts, 0, 1, 1, 1)
        self.button_checkmk_view_hosts_reset = QtWidgets.QPushButton(self.groupbox_checkmk_views)
        self.button_checkmk_view_hosts_reset.setObjectName("button_checkmk_view_hosts_reset")
        self.gridLayout_4.addWidget(self.button_checkmk_view_hosts_reset, 0, 2, 1, 1)
        self.button_checkmk_view_services_reset = QtWidgets.QPushButton(self.groupbox_checkmk_views)
        self.button_checkmk_view_services_reset.setObjectName("button_checkmk_view_services_reset")
        self.gridLayout_4.addWidget(self.button_checkmk_view_services_reset, 1, 2, 1, 1)
        self.gridLayout_3.addWidget(self.groupbox_checkmk_views, 25, 1, 1, 3)
        self.label_host_filter = QtWidgets.QLabel(self.groupbox_options)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_host_filter.sizePolicy().hasHeightForWidth())
        self.label_host_filter.setSizePolicy(sizePolicy)
        self.label_host_filter.setObjectName("label_host_filter")
        self.gridLayout_3.addWidget(self.label_host_filter, 10, 1, 1, 1)
        self.input_checkbox_ignore_cert = QtWidgets.QCheckBox(self.groupbox_options)
        self.input_checkbox_ignore_cert.setObjectName("input_checkbox_ignore_cert")
        self.gridLayout_3.addWidget(self.input_checkbox_ignore_cert, 0, 1, 1, 3)
        self.input_lineedit_map_to_servicename = QtWidgets.QLineEdit(self.groupbox_options)
        self.input_lineedit_map_to_servicename.setObjectName("input_lineedit_map_to_servicename")
        self.gridLayout_3.addWidget(self.input_lineedit_map_to_servicename, 14, 2, 1, 2)
        self.input_lineedit_host_filter = QtWidgets.QLineEdit(self.groupbox_options)
        self.input_lineedit_host_filter.setText("")
        self.input_lineedit_host_filter.setObjectName("input_lineedit_host_filter")
        self.gridLayout_3.addWidget(self.input_lineedit_host_filter, 10, 2, 1, 2)
        self.label_custom_ca_file = QtWidgets.QLabel(self.groupbox_options)
        self.label_custom_ca_file.setObjectName("label_custom_ca_file")
        self.gridLayout_3.addWidget(self.label_custom_ca_file, 2, 1, 1, 1)
        self.label_map_to_status_information = QtWidgets.QLabel(self.groupbox_options)
        self.label_map_to_status_information.setObjectName("label_map_to_status_information")
        self.gridLayout_3.addWidget(self.label_map_to_status_information, 15, 1, 1, 1)
        self.input_lineedit_monitor_site = QtWidgets.QLineEdit(self.groupbox_options)
        self.input_lineedit_monitor_site.setObjectName("input_lineedit_monitor_site")
        self.gridLayout_3.addWidget(self.input_lineedit_monitor_site, 8, 2, 1, 1)
        self.input_checkbox_use_display_name_host = QtWidgets.QCheckBox(self.groupbox_options)
        self.input_checkbox_use_display_name_host.setObjectName("input_checkbox_use_display_name_host")
        self.gridLayout_3.addWidget(self.input_checkbox_use_display_name_host, 21, 1, 1, 3)
        self.input_lineedit_map_to_warning = QtWidgets.QLineEdit(self.groupbox_options)
        self.input_lineedit_map_to_warning.setObjectName("input_lineedit_map_to_warning")
        self.gridLayout_3.addWidget(self.input_lineedit_map_to_warning, 17, 2, 1, 2)
        self.input_lineedit_map_to_critical = QtWidgets.QLineEdit(self.groupbox_options)
        self.input_lineedit_map_to_critical.setObjectName("input_lineedit_map_to_critical")
        self.gridLayout_3.addWidget(self.input_lineedit_map_to_critical, 18, 2, 1, 2)
        self.input_lineedit_map_to_unknown = QtWidgets.QLineEdit(self.groupbox_options)
        self.input_lineedit_map_to_unknown.setObjectName("input_lineedit_map_to_unknown")
        self.gridLayout_3.addWidget(self.input_lineedit_map_to_unknown, 19, 2, 1, 2)
        self.label_map_to_ok = QtWidgets.QLabel(self.groupbox_options)
        self.label_map_to_ok.setObjectName("label_map_to_ok")
        self.gridLayout_3.addWidget(self.label_map_to_ok, 16, 1, 1, 1)
        self.label_map_to_warning = QtWidgets.QLabel(self.groupbox_options)
        self.label_map_to_warning.setObjectName("label_map_to_warning")
        self.gridLayout_3.addWidget(self.label_map_to_warning, 17, 1, 1, 1)
        self.label_map_to_critical = QtWidgets.QLabel(self.groupbox_options)
        self.label_map_to_critical.setObjectName("label_map_to_critical")
        self.gridLayout_3.addWidget(self.label_map_to_critical, 18, 1, 1, 1)
        self.label_map_to_unknown = QtWidgets.QLabel(self.groupbox_options)
        self.label_map_to_unknown.setObjectName("label_map_to_unknown")
        self.gridLayout_3.addWidget(self.label_map_to_unknown, 19, 1, 1, 1)
        self.gridLayout.addWidget(self.groupbox_options, 28, 0, 1, 4)

        self.retranslateUi(settings_server)
        QtCore.QMetaObject.connectSlotsByName(settings_server)
        settings_server.setTabOrder(self.input_checkbox_enabled, self.input_combobox_type)
        settings_server.setTabOrder(self.input_combobox_type, self.input_lineedit_name)
        settings_server.setTabOrder(self.input_lineedit_name, self.input_lineedit_monitor_url)
        settings_server.setTabOrder(self.input_lineedit_monitor_url, self.input_lineedit_monitor_cgi_url)
        settings_server.setTabOrder(self.input_lineedit_monitor_cgi_url, self.input_lineedit_username)
        settings_server.setTabOrder(self.input_lineedit_username, self.input_lineedit_password)
        settings_server.setTabOrder(self.input_lineedit_password, self.input_checkbox_save_password)
        settings_server.setTabOrder(self.input_checkbox_save_password, self.input_checkbox_use_proxy)
        settings_server.setTabOrder(self.input_checkbox_use_proxy, self.input_lineedit_proxy_address)
        settings_server.setTabOrder(self.input_lineedit_proxy_address, self.input_lineedit_proxy_username)
        settings_server.setTabOrder(self.input_lineedit_proxy_username, self.input_lineedit_proxy_password)
        settings_server.setTabOrder(self.input_lineedit_proxy_password, self.input_checkbox_use_proxy_from_os)

    def retranslateUi(self, settings_server):
        _translate = QtCore.QCoreApplication.translate
        settings_server.setWindowTitle(_translate("settings_server", "Dialog"))
        self.label_password.setText(_translate("settings_server", "Password:"))
        self.input_lineedit_monitor_url.setText(_translate("settings_server", "https://monitor-server"))
        self.label_name.setText(_translate("settings_server", "Monitor name:"))
        self.input_lineedit_username.setText(_translate("settings_server", "username"))
        self.input_lineedit_monitor_cgi_url.setText(_translate("settings_server", "https://monitor-server/monitor/cgi-bin"))
        self.input_lineedit_password.setText(_translate("settings_server", "1234567890"))
        self.input_checkbox_use_proxy.setText(_translate("settings_server", "Use proxy"))
        self.groupbox_proxy.setTitle(_translate("settings_server", "Proxy:"))
        self.label_proxy_password.setText(_translate("settings_server", "Proxy password:"))
        self.label_proxy_username.setText(_translate("settings_server", "Proxy username:"))
        self.input_lineedit_proxy_username.setText(_translate("settings_server", "proxyusername"))
        self.input_lineedit_proxy_address.setText(_translate("settings_server", "http://proxy:port/"))
        self.label_proxy_address.setText(_translate("settings_server", "Proxy address:"))
        self.input_lineedit_proxy_password.setText(_translate("settings_server", "1234567890"))
        self.input_checkbox_use_proxy_from_os.setText(_translate("settings_server", "Use proxy from OS"))
        self.label_server_type.setText(_translate("settings_server", "Monitor type:"))
        self.label_username.setText(_translate("settings_server", "Username:"))
        self.label_monitor_url.setText(_translate("settings_server", "Monitor URL:"))
        self.input_lineedit_name.setText(_translate("settings_server", "Monitor server"))
        self.label_monitor_cgi_url.setText(_translate("settings_server", "Monitor CGI URL:"))
        self.input_checkbox_enabled.setText(_translate("settings_server", "Enabled"))
        self.input_checkbox_save_password.setText(_translate("settings_server", "Save password"))
        self.input_checkbox_show_options.setText(_translate("settings_server", "Show more options"))
        self.groupbox_options.setTitle(_translate("settings_server", "Options:"))
        self.button_choose_custom_cert_ca_file.setText(_translate("settings_server", "Choose file..."))
        self.input_checkbox_use_autologin.setText(_translate("settings_server", "Use autologin"))
        self.label_map_to_hostname.setText(_translate("settings_server", "Map to hostname:"))
        self.input_checkbox_use_display_name_service.setText(_translate("settings_server", "Use display name as service name"))
        self.label_idp_ecp_endpoint.setText(_translate("settings_server", "IdP ECP endpoint URL"))
        self.label_alertmanager_filter.setText(_translate("settings_server", "Filter:"))
        self.label_map_to_servicename.setText(_translate("settings_server", "Map to servicename:"))
        self.input_checkbox_custom_cert_use.setText(_translate("settings_server", "Use custom CA file"))
        self.label_timeout.setText(_translate("settings_server", "Timeout:"))
        self.input_checkbox_force_authuser.setText(_translate("settings_server", "Only show permitted hosts for \"see all\" users (1.4.0i1 or newer)"))
        self.input_checkbox_no_cookie_auth.setText(_translate("settings_server", "Do not use cookie authentication"))
        self.label_autologin_key.setText(_translate("settings_server", "Autologin Key:"))
        self.label_auth_type.setText(_translate("settings_server", "Authentication:"))
        self.label_service_filter.setText(_translate("settings_server", "Service filter:"))
        self.label_timeout_sec.setText(_translate("settings_server", "seconds"))
        self.label_monitor_site.setText(_translate("settings_server", "Monitor Site:"))
        self.input_checkbox_use_description_name_service.setText(_translate("settings_server", "Use description as service name"))
        self.groupbox_checkmk_views.setTitle(_translate("settings_server", "Views:"))
        self.label_checkmk_view_hosts.setText(_translate("settings_server", "Hosts:"))
        self.label_checkmk_view_services.setText(_translate("settings_server", "Services:"))
        self.button_checkmk_view_hosts_reset.setText(_translate("settings_server", "Reset"))
        self.button_checkmk_view_services_reset.setText(_translate("settings_server", "Reset"))
        self.label_host_filter.setText(_translate("settings_server", "Host filter:"))
        self.input_checkbox_ignore_cert.setText(_translate("settings_server", "Ignore SSL/TLS certificate"))
        self.label_custom_ca_file.setText(_translate("settings_server", "Custom CA file: "))
        self.label_map_to_status_information.setText(_translate("settings_server", "Map to status_information:"))
        self.input_lineedit_monitor_site.setText(_translate("settings_server", "Site 1"))
        self.input_checkbox_use_display_name_host.setText(_translate("settings_server", "Use display name as host name"))
        self.label_map_to_ok.setText(_translate("settings_server", "Map to OK"))
        self.label_map_to_warning.setText(_translate("settings_server", "Map to WARNING"))
        self.label_map_to_critical.setText(_translate("settings_server", "Map to CRITICAL"))
        self.label_map_to_unknown.setText(_translate("settings_server", "Map to UNKNOWN"))



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'dialog_server_missing.ui'
#
# Created by: PyQt5 UI code generator 5.5.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_dialog_server_missing(object):
    def setupUi(self, dialog_server_missing):
        dialog_server_missing.setObjectName("dialog_server_missing")
        dialog_server_missing.resize(813, 263)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(dialog_server_missing.sizePolicy().hasHeightForWidth())
        dialog_server_missing.setSizePolicy(sizePolicy)
        dialog_server_missing.setMinimumSize(QtCore.QSize(350, 0))
        dialog_server_missing.setModal(True)
        self.verticalLayout = QtWidgets.QVBoxLayout(dialog_server_missing)
        self.verticalLayout.setObjectName("verticalLayout")
        self.label_no_server_configured = QtWidgets.QLabel(dialog_server_missing)
        self.label_no_server_configured.setWordWrap(True)
        self.label_no_server_configured.setObjectName("label_no_server_configured")
        self.verticalLayout.addWidget(self.label_no_server_configured)
        self.label_no_server_enabled = QtWidgets.QLabel(dialog_server_missing)
        self.label_no_server_enabled.setWordWrap(True)
        self.label_no_server_enabled.setObjectName("label_no_server_enabled")
        self.verticalLayout.addWidget(self.label_no_server_enabled)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.button_enable_server = QtWidgets.QPushButton(dialog_server_missing)
        self.button_enable_server.setObjectName("button_enable_server")
        self.horizontalLayout.addWidget(self.button_enable_server)
        self.button_create_server = QtWidgets.QPushButton(dialog_server_missing)
        self.button_create_server.setObjectName("button_create_server")
        self.horizontalLayout.addWidget(self.button_create_server)
        self.button_ignore = QtWidgets.QPushButton(dialog_server_missing)
        self.button_ignore.setObjectName("button_ignore")
        self.horizontalLayout.addWidget(self.button_ignore)
        self.button_exit = QtWidgets.QPushButton(dialog_server_missing)
        self.button_exit.setObjectName("button_exit")
        self.horizontalLayout.addWidget(self.button_exit)
        self.verticalLayout.addLayout(self.horizontalLayout)

        self.retranslateUi(dialog_server_missing)
        QtCore.QMetaObject.connectSlotsByName(dialog_server_missing)

    def retranslateUi(self, dialog_server_missing):
        _translate = QtCore.QCoreApplication.translate
        dialog_server_missing.setWindowTitle(_translate("dialog_server_missing", "Nagstamon"))
        self.label_no_server_configured.setText(_translate("dialog_server_missing", "<html><head/><body><p>There are no configured servers yet.<br/></p></body></html>"))
        self.label_no_server_enabled.setText(_translate("dialog_server_missing", "<html><head/><body><p>There are no servers enabled.<br/></p></body></html>"))
        self.button_enable_server.setText(_translate("dialog_server_missing", "Enable server"))
        self.button_create_server.setText(_translate("dialog_server_missing", "Create new server"))
        self.button_ignore.setText(_translate("dialog_server_missing", "Ignore"))
        self.button_exit.setText(_translate("dialog_server_missing", "Exit"))




# encoding: utf-8

# Nagstamon - Nagios status monitor for your desktop
# Copyright (C) 2008-2021 Henri Wahl <henri@nagstamon.de> et al.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# The initial implementation was contributed to the Nagstamon project
# by tribe29 GmbH.

import sys
import urllib.request, urllib.parse, urllib.error
import time
import copy
import html

from Nagstamon.Objects import (GenericHost,
                               GenericService,
                               Result)
from Nagstamon.Servers.Generic import GenericServer
from Nagstamon.Helpers import webbrowser_open
from Nagstamon.Config import conf

class MultisiteError(Exception):
    def __init__(self, terminate, result):
        self.terminate = terminate
        self.result    = result


class MultisiteServer(GenericServer):
    """
       special treatment for Checkmk Multisite JSON API
    """
    TYPE = 'Checkmk Multisite'

    # URLs for browser shortlinks/buttons on popup window
    BROWSER_URLS= { 'monitor': '$MONITOR$',
                    'hosts': '$MONITOR$/index.py?start_url=view.py?view_name=hostproblems',
                    'services': '$MONITOR$/index.py?start_url=view.py?view_name=svcproblems',
                    'history': '$MONITOR$/index.py?start_url=view.py?view_name=events'}

    def __init__(self, **kwds):
        GenericServer.__init__(self, **kwds)

        # Prepare all urls needed by nagstamon -
        self.urls = {}
        self.statemap = {}

        # Entries for monitor default actions in context menu
        self.MENU_ACTIONS = ['Monitor', 'Recheck', 'Acknowledge', 'Downtime']

        # flag for newer cookie authentication
        self.CookieAuth = False


    def init_HTTP(self):
        # general initialization
        GenericServer.init_HTTP(self)

        # Fix eventually missing tailing '/' in url
        # if self.monitor_url[-1] != '/':
        #     self.monitor_url += '/'
        if self.monitor_url.endswith('/'):
            self.monitor_url.rstrip('/')

        # Prepare all urls needed by nagstamon if not yet done
        if len(self.urls) == len(self.statemap):
            self.urls = {
              'api_services':    self.monitor_url + '/view.py?view_name={0}&output_format=python&lang=&limit=hard'.\
                                                                          format(self.checkmk_view_services),
              'human_services':  self.monitor_url + '/index.py?%s' % \
                                                   urllib.parse.urlencode({'start_url': 'view.py?view_name={0}'.\
                                                                          format(self.checkmk_view_services)}),
              'human_service':   self.monitor_url + '/index.py?%s' %
                                                   urllib.parse.urlencode({'start_url': 'view.py?view_name=service'}),

              'api_hosts':       self.monitor_url + '/view.py?view_name={0}&output_format=python&lang=&limit=hard'.\
                                                                          format(self.checkmk_view_hosts),
              'human_hosts':     self.monitor_url + '/index.py?%s' %
                                                   urllib.parse.urlencode({'start_url': 'view.py?view_name={0}'.\
                                                                           format(self.checkmk_view_services)}),
              'human_host':      self.monitor_url + '/index.py?%s' %
                                                   urllib.parse.urlencode({'start_url': 'view.py?view_name=hoststatus'}),
              # URLs do not need pythonic output because since werk #0766 API does not work with transid=-1 anymore
              # thus access to normal webinterface is used
              'api_host_act':    self.monitor_url + '/view.py?_transid=-1&_do_actions=yes&_do_confirm=Yes!&view_name=hoststatus&filled_in=actions&lang=',
              'api_service_act': self.monitor_url + '/view.py?_transid=-1&_do_actions=yes&_do_confirm=Yes!&view_name=service&filled_in=actions&lang=',
              'api_svcprob_act': self.monitor_url + '/view.py?_transid=-1&_do_actions=yes&_do_confirm=Yes!&view_name=svcproblems&filled_in=actions&lang=',
              'human_events':    self.monitor_url + '/index.py?%s' %
                                                   urllib.parse.urlencode({'start_url': 'view.py?view_name=events'}),
              'transid':         self.monitor_url + '/view.py?actions=yes&filled_in=actions&host=$HOST$&service=$SERVICE$&view_name=service'
            }

            self.statemap = {
                'UNREACH': 'UNREACHABLE',
                'CRIT':    'CRITICAL',
                'WARN':    'WARNING',
                'UNKN':    'UNKNOWN',
                'PEND':    'PENDING',
            }

        if self.CookieAuth and not self.refresh_authentication:
            # get cookie to access Checkmk web interface
            if 'cookies' in dir(self.session):
                if len(self.session.cookies) == 0:
                    # if no cookie yet login
                    self._get_cookie_login()
            elif self.session == None:
                # if no cookie yet login
                self._get_cookie_login()


    def init_config(self):
        """
            dummy init_config, called at thread start, not really needed here, just omit extra properties
        """
        pass


    def _is_auth_in_cookies(self):
        """
            check if there is any valid auth session in cookies which has the name 'auth_<monitor_name>'
        """
        if not self.session == None:
            for cookie in self.session.cookies:
                if cookie.name.startswith('auth_'):
                    return True
        return False

    def _get_url(self, url):
        result = self.FetchURL(url, 'raw')
        content, error, status_code = result.result, result.error, result.status_code

        if error != '' or status_code >= 400:
            raise MultisiteError(True, Result(result=content,
                                              error=error,
                                              status_code=status_code))

        if content.startswith('WARNING:'):
            c = content.split('\n')

            # Print non ERRORS to the log in debug mode
            self.Debug(server=self.get_name(), debug=c[0])

            raise MultisiteError(False, Result(result='\n'.join(c[1:]),
                                               error=c[0],
                                               status_code=status_code))

        elif content.startswith('ERROR:'):
            raise MultisiteError(True, Result(result=content,
                                              error=content,
                                              status_code=status_code))

        # in case of auth problem enable GUI auth part in popup
        if self.CookieAuth == True and not self.session == None:
            if not self._is_auth_in_cookies():
                self.refresh_authentication = True
                return ''

        # looks like cookieauth
        elif content.startswith('<'):
            self.CookieAuth = True
            # if first attempt login and then try to get data again
            if not self._is_auth_in_cookies():
                self._get_cookie_login()
                result = self.FetchURL(url, 'raw')
                content, error = result.result, result.error
                if content.startswith('<'):
                    return ''

        # if finally still some <HTML> is sent this looks like a new login due to password change
        if content.startswith('<'):
            self.refresh_authentication = True
            return ''

        return eval(content)

    def _get_cookie_login(self):
        """
            login on cookie monitor site
        """
        # put all necessary data into url string
        login_data = {'_username': self.get_username(),
                     '_password': self.get_password(),
                     '_login': '1',
                     '_origtarget' : '',
                     'filled_in' :' login'}
        # get cookie from login page via url retrieving as with other urls
        try:
            # login and get cookie
            self.FetchURL(self.monitor_url + '/login.py', cgi_data=login_data, multipart=True)
        except:
            import traceback
            traceback.print_exc(file=sys.stdout)

            self.Error(sys.exc_info())


    def _get_status(self):
        """
            Get status from Checkmk Server
        """

        ret = Result()

        # Create URLs for the configured filters
        url_params = ''

        if self.force_authuser:
            url_params += "&force_authuser=1"

        url_params += '&is_host_acknowledged=-1&is_service_acknowledged=-1'
        url_params += '&is_host_notifications_enabled=-1&is_service_notifications_enabled=-1'
        url_params += '&is_host_active_checks_enabled=-1&is_service_active_checks_enabled=-1'
        url_params += '&host_scheduled_downtime_depth=-1&is_in_downtime=-1'

        try:
            response = []
            try:
                response = self._get_url(self.urls['api_hosts'] + url_params)
            except MultisiteError as e:
                if e.terminate:
                    return e.result

            if response == '':
                return Result(result='',
                              error='Login failed',
                              status_code=401)

            for row in response[1:]:
                host= dict(list(zip(copy.deepcopy(response[0]), copy.deepcopy(row))))
                n = {
                    'host':               host['host'],
                    'status':             self.statemap.get(host['host_state'], host['host_state']),
                    'last_check':         host['host_check_age'],
                    'duration':           host['host_state_age'],
                    'status_information': html.unescape(host['host_plugin_output'].replace('\n', ' ')),
                    'attempt':            host['host_attempt'],
                    'site':               host['sitename_plain'],
                    'address':            host['host_address']
                }

                # host objects contain service objects
                if n['host'] not in self.new_hosts:
                    new_host = n['host']
                    self.new_hosts[new_host] = GenericHost()
                    self.new_hosts[new_host].name = n['host']
                    self.new_hosts[new_host].server = self.name
                    self.new_hosts[new_host].status = n['status']
                    self.new_hosts[new_host].last_check = n['last_check']
                    self.new_hosts[new_host].duration = n['duration']
                    self.new_hosts[new_host].attempt = n['attempt']
                    self.new_hosts[new_host].status_information= html.unescape(n['status_information'].replace('\n', ' '))
                    self.new_hosts[new_host].site = n['site']
                    self.new_hosts[new_host].address = n['address']

                    # transisition to Checkmk 1.1.10p2
                    if 'host_in_downtime' in host:
                        if host['host_in_downtime'] == 'yes':
                            self.new_hosts[new_host].scheduled_downtime = True
                    if 'host_acknowledged' in host:
                        if host['host_acknowledged'] == 'yes':
                            self.new_hosts[new_host].acknowledged = True
                    if 'host_notifications_enabled' in host:
                        if host['host_notifications_enabled'] == 'no':
                            self.new_hosts[new_host].notifications_disabled = True

                    # hard/soft state for later filter evaluation
                    real_attempt, max_attempt = self.new_hosts[new_host].attempt.split('/')
                    if real_attempt != max_attempt:
                        self.new_hosts[new_host].status_type = 'soft'
                    else:
                        self.new_hosts[new_host].status_type = 'hard'

            del response

        except:
            import traceback
            traceback.print_exc(file=sys.stdout)

            self.isChecking = False
            result, error = self.Error(sys.exc_info())
            return Result(result=result, error=error)

        # Add filters to the url which should only be applied to the service request
        if conf.filter_services_on_unreachable_hosts == True:
            # thanks to https://github.com/HenriWahl/Nagstamon/issues/510
            url_params += '&hst0=On&hst1=On'

        # services
        try:
            response = []
            try:
                response = self._get_url(self.urls['api_services'] + url_params)
            except MultisiteError as e:
                if e.terminate:
                    return e.result
                else:
                    response = copy.deepcopy(e.result.content)
                    ret = copy.deepcopy(e.result)

            for row in response[1:]:
                service = dict(list(zip(copy.deepcopy(response[0]), copy.deepcopy(row))))
                n = {
                    'host':               service['host'],
                    'service':            service['service_description'],
                    'status':             self.statemap.get(service['service_state'], service['service_state']),
                    'last_check':         service['svc_check_age'],
                    'duration':           service['svc_state_age'],
                    'attempt':            service['svc_attempt'],
                    'status_information': html.unescape(service['svc_plugin_output'].replace('\n', ' ')),
                    # Checkmk passive services can be re-scheduled by using the Checkmk service
                    'passiveonly':        service['svc_is_active'] == 'no' and not service['svc_check_command'].startswith('check_mk'),
                    'flapping':           service['svc_flapping'] == 'yes',
                    'site':               service['sitename_plain'],
                    'address':            service['host_address'],
                    'command':            service['svc_check_command'],
                }

                # host objects contain service objects
                if n['host'] not in self.new_hosts:
                    self.new_hosts[n['host']] = GenericHost()
                    self.new_hosts[n['host']].name = n['host']
                    self.new_hosts[n['host']].status = 'UP'
                    self.new_hosts[n['host']].site = n['site']
                    self.new_hosts[n['host']].address = n['address']
                # if a service does not exist create its object
                if n['service'] not in self.new_hosts[n['host']].services:
                    new_service = n['service']
                    self.new_hosts[n['host']].services[new_service] = GenericService()
                    self.new_hosts[n['host']].services[new_service].host = n['host']
                    self.new_hosts[n['host']].services[new_service].server = self.name
                    self.new_hosts[n['host']].services[new_service].name = n['service']
                    self.new_hosts[n['host']].services[new_service].status = n['status']
                    self.new_hosts[n['host']].services[new_service].last_check = n['last_check']
                    self.new_hosts[n['host']].services[new_service].duration = n['duration']
                    self.new_hosts[n['host']].services[new_service].attempt = n['attempt']
                    self.new_hosts[n['host']].services[new_service].status_information = n['status_information'].strip()
                    self.new_hosts[n['host']].services[new_service].passiveonly = n['passiveonly']
                    self.new_hosts[n['host']].services[new_service].flapping = n['flapping']
                    self.new_hosts[n['host']].services[new_service].site = n['site']
                    self.new_hosts[n['host']].services[new_service].address = n['address']
                    self.new_hosts[n['host']].services[new_service].command = n['command']

                    # transistion to Checkmk 1.1.10p2
                    if 'svc_in_downtime' in service:
                        if service['svc_in_downtime'] == 'yes':
                            self.new_hosts[n['host']].services[new_service].scheduled_downtime = True
                    if 'svc_acknowledged' in service:
                        if service['svc_acknowledged'] == 'yes':
                            self.new_hosts[n['host']].services[new_service].acknowledged = True
                    if 'svc_flapping' in service:
                        if service['svc_flapping'] == 'yes':
                            self.new_hosts[n['host']].services[new_service].flapping = True
                    if 'svc_notifications_enabled' in service:
                        if service['svc_notifications_enabled'] == 'no':
                            self.new_hosts[n['host']].services[new_service].notifications_disabled = True

                    # hard/soft state for later filter evaluation
                    real_attempt, max_attempt = self.new_hosts[n['host']].services[new_service].attempt.split('/')
                    if real_attempt != max_attempt:
                        self.new_hosts[n['host']].services[new_service].status_type = 'soft'
                    else:
                        self.new_hosts[n['host']].services[new_service].status_type = 'hard'

            del response

        except:
            import traceback
            traceback.print_exc(file=sys.stdout)

            # set checking flag back to False
            self.isChecking = False
            result, error = self.Error(sys.exc_info())
            return Result(result=copy.deepcopy(result), error=copy.deepcopy(error))

        del url_params

        return ret


    def open_monitor(self, host, service=''):
        """
            open monitor from treeview context menu
        """

        if service == '':
            url = self.urls['human_host'] + urllib.parse.urlencode({'x': 'site='+self.hosts[host].site+'&host='+host}).replace('x=', '%26')
        else:
            url = self.urls['human_service'] + urllib.parse.urlencode({'x': 'site='+self.hosts[host].site+'&host='+host+'&service='+service}).replace('x=', '%26')

        if conf.debug_mode == True:
            self.Debug(server=self.get_name(), host=host, service=service, debug='Open host/service monitor web page ' + url)
        webbrowser_open(url)


    def GetHost(self, host):
        """
            find out ip or hostname of given host to access hosts/devices which do not appear in DNS but
            have their ip saved in Nagios
        """

        # the fastest method is taking hostname as used in monitor
        if conf.connect_by_host == True or host == '':
            return Result(result=host)

        ip = ''

        try:
            if host in self.hosts:
                ip = self.hosts[host].address

            if conf.debug_mode == True:
                self.Debug(server=self.get_name(), host=host, debug ='IP of %s:' % (host) + ' ' + ip)

            if conf.connect_by_dns == True:
                try:
                    address = socket.gethostbyaddr(ip)[0]
                except:
                    address = ip
            else:
                address = ip
        except:
            result, error = self.Error(sys.exc_info())
            return Result(result=result, error=error)

        return Result(result=address)


    def get_start_end(self, host):
        return time.strftime('%Y-%m-%d %H:%M'), time.strftime('%Y-%m-%d %H:%M', time.localtime(time.time() + 7200))


    def _action(self, site, host, service, specific_params):
        params = {
            'site':    self.hosts[host].site,
            'host':    host,
        }
        params.update(specific_params)

        # decide about service or host url
        if service != '':
            url = self.urls['api_service_act']
        else:
            url = self.urls['api_host_act']

        # set service
        params['service'] = service

        # get current transid
        transid = self._get_transid(host, service)
        url = url.replace('?_transid=-1&', '?_transid=%s&' % (transid))

        if conf.debug_mode == True:
            self.Debug(server=self.get_name(), host=host, debug ='Submitting action: ' + url + '&' + urllib.parse.urlencode(params))

        # apply action
        self.FetchURL(url + '&' + urllib.parse.urlencode(params))


    def _set_downtime(self, host, service, author, comment, fixed, start_time, end_time, hours, minutes):
        try:
            # might be more sophisticated, especially if there is a localized Checkmk web interface
            from_date, from_time = start_time.split(' ')
            from_year, from_month, from_day = from_date.split('-')
            from_hour, from_min = from_time.split(':')
            to_date, to_time = end_time.split(' ')
            to_year, to_month, to_day = to_date.split('-')
            to_hour, to_min = to_time.split(':')

            # let's try to push downtime info in all variants to server - somewhat holzhammery but well...
            params = {
                '_down_comment': author == self.username and comment or '%s: %s' % (author, comment),
                '_down_flexible': fixed == 0 and 'on' or '',
                '_down_custom': 'Custom+time+range',
                '_down_from_date': from_date,
                '_down_from_time': from_time,
                '_down_to_date': to_date,
                '_down_to_time': to_time,
                '_down_duration': '%s:%s' % (hours, minutes),
                '_down_from_year': from_year,
                '_down_from_month': from_month,
                '_down_from_day': from_day,
                '_down_from_hour': from_hour,
                '_down_from_min': from_min,
                '_down_from_sec': '00',
                '_down_to_year': to_year,
                '_down_to_month': to_month,
                '_down_to_day': to_day,
                '_down_to_hour': to_hour,
                '_down_to_min': to_min,
                '_down_to_sec': '00',
                'actions': 'yes'
            }
            # service needs extra parameter
            if service:
                params['_do_confirm_service_downtime'] = 'Schedule+downtime+for+1+service'
            self._action(self.hosts[host].site, host, service, params)
        except:
            if conf.debug_mode:
                self.Debug(server=self.get_name(), host=host,
                           debug='Invalid start/end date/time given')


    def _set_acknowledge(self, host, service, author, comment, sticky, notify, persistent, all_services=[]):
        p = {
            '_acknowledge':    'Acknowledge',
            '_ack_sticky':     sticky == 1 and 'on' or '',
            '_ack_notify':     notify == 1 and 'on' or '',
            '_ack_persistent': persistent == 1 and 'on' or '',
            '_ack_comment':    author == self.username and comment or '%s: %s' % (author, comment)
        }
        self._action(self.hosts[host].site, host, service, p)

        # acknowledge all services on a host when told to do so
        for s in all_services:
            self._action(self.hosts[host].site, host, s, p)


    def _set_recheck(self, host, service):
        p = {
            '_resched_checks': 'Reschedule active checks',
            '_resched_pread':  '0'
        }
        self._action(self.hosts[host].site, host, service, p)


    def recheck_all(self):
        """
            special method for Checkmk as there is one URL for rescheduling all problems to be checked
        """
        params = dict()
        params['_resched_checks'] = 'Reschedule active checks'
        url = self.urls['api_svcprob_act']

        if conf.debug_mode == True:
            self.Debug(server=self.get_name(), debug ='Rechecking all action: ' + url + '&' + urllib.parse.urlencode(params))

        result = self.FetchURL(url + '&' + urllib.parse.urlencode(params), giveback = 'raw')


    def _get_transid(self, host, service):
        """
            get transid for an action
        """
        # since Checkmk 2.0 it seems to be a problem if service is empty so fill it with a definitively existing one
        if not service:
            service = 'PING'
        transid = self.FetchURL(self.urls['transid'].replace('$HOST$', host).replace('$SERVICE$', service.replace(' ', '+')),
                                'obj').result.find(attrs={'name' : '_transid'})['value']
        return transid
